aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/device/xps
diff options
context:
space:
mode:
authorGravatar robertphillips@google.com <robertphillips@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-08-20 17:49:04 +0000
committerGravatar robertphillips@google.com <robertphillips@google.com@2bbb7eff-a529-9590-31e7-b0007b416f81>2013-08-20 17:49:04 +0000
commit3055b700189afdd02486ed8f2279cea1d8897243 (patch)
treea66e6ce6e9717464dd67eb206f76440da9bab059 /include/device/xps
parent4eaa6647e70c9404d1c920f674d706ca2d2a76b9 (diff)
Split SkDevice out of SkBitmapDevice
Diffstat (limited to 'include/device/xps')
-rw-r--r--include/device/xps/SkXPSDevice.h17
1 files changed, 8 insertions, 9 deletions
diff --git a/include/device/xps/SkXPSDevice.h b/include/device/xps/SkXPSDevice.h
index dab8d1f6a3..91307a595e 100644
--- a/include/device/xps/SkXPSDevice.h
+++ b/include/device/xps/SkXPSDevice.h
@@ -30,7 +30,7 @@
The drawing context for the XPS backend.
*/
-class SkXPSDevice : public SkDevice {
+class SkXPSDevice : public SkBitmapDevice {
public:
SK_API SkXPSDevice();
SK_API virtual ~SkXPSDevice();
@@ -134,7 +134,7 @@ protected:
virtual void drawDevice(
const SkDraw&,
- SkDevice* device,
+ SkBaseDevice* device,
int x, int y,
const SkPaint& paint) SK_OVERRIDE;
@@ -307,18 +307,17 @@ private:
const SkVector& ppuScale,
IXpsOMPath* shadedPath);
- // override from SkDevice
- virtual SkDevice* onCreateCompatibleDevice(
- SkBitmap::Config config,
- int width, int height,
- bool isOpaque,
- Usage usage) SK_OVERRIDE;
+ // override from SkBaseDevice
+ virtual SkBaseDevice* onCreateCompatibleDevice(SkBitmap::Config config,
+ int width, int height,
+ bool isOpaque,
+ Usage usage) SK_OVERRIDE;
// Disable the default copy and assign implementation.
SkXPSDevice(const SkXPSDevice&);
void operator=(const SkXPSDevice&);
- typedef SkDevice INHERITED;
+ typedef SkBitmapDevice INHERITED;
};
#endif